@@ -1,13 +1,10 @@
 #!/usr/bin/python3
 
-from debmutate.control import (
-    drop_dependency,
-    ControlEditor,
-    )
-from lintian_brush.fixer import report_result, fixed_lintian_tag
+from debmutate.control import drop_dependency
+from lintian_brush.fixer import control, report_result, LintianIssue
 
 
-with ControlEditor() as updater:
+with control as updater:
     for field in ['Build-Depends', 'Build-Depends-Indep']:
         try:
             updater.source[field] = drop_dependency(
@@ -15,9 +12,11 @@ with ControlEditor() as updater:
         except KeyError:
             pass
         else:
-            fixed_lintian_tag(
+            issue = LintianIssue(
                 updater.source, 'build-depends-on-build-essential',
-                field.lower())
+                field)
+            # TODO(jelmer): Check overrides
+            issue.report_fixed()
 
 
 report_result("Drop unnecessary dependency on build-essential.")
