@@ -4,8 +4,8 @@ from debian.copyright import (
     LicenseParagraph,
     NotMachineReadableError,
     )
-from lintian_brush.copyright import CopyrightUpdater
-from lintian_brush.fixer import report_result
+from debmutate.copyright import CopyrightEditor
+from lintian_brush.fixer import report_result, fixed_lintian_tag
 
 
 def fix_header_license_references(copyright):
@@ -28,17 +28,19 @@ def fix_header_license_references(copyright):
             copyright.add_license_paragraph(
                 LicenseParagraph.create(
                     copyright.header.license))
+    fixed_lintian_tag(
+        'source',
+        'dep5-file-paragraph-references-header-paragraph',
+        f'{copyright.header.license.synopsis} (line XX)')
     return copyright.header.license
 
 
 try:
-    with CopyrightUpdater() as updater:
+    with CopyrightEditor() as updater:
         license = fix_header_license_references(updater.copyright)
 except (FileNotFoundError, NotMachineReadableError):
     pass
 else:
     if license:
         report_result(
-            'Add missing license paragraph for %s' % license.synopsis,
-            fixed_lintian_tags=[
-                'dep5-file-paragraph-references-header-paragraph'])
+            'Add missing license paragraph for %s' % license.synopsis)
