@@ -13,7 +13,7 @@ from lintian_brush.fixer import (
 if not opinionated():
     sys.exit(0)
 
-with suppress(FileNotFoundError), open('debian/patches/series', 'r') as f:
+with suppress(FileNotFoundError), open('debian/patches/series') as f:
     if not f.read().strip():
         os.unlink('debian/patches/series')
 
