@@ -5,7 +5,7 @@ from lintian_brush.fixer import report_result
 
 import os
 
-with suppress(FileNotFoundError), open('debian/source/options', 'r') as f:
+with suppress(FileNotFoundError), open('debian/source/options') as f:
     if not f.read().strip():
         os.unlink('debian/source/options')
 
