@@ -48,8 +48,8 @@ if typo_fixed:
     kind += 'typo' + ('s' if len(typo_fixed) > 1 else '')
 
 fixed_str = ', '.join(
-    ['%s ⇒ %s' % (old, new)
+    [f'{old} ⇒ {new}'
      for (old, new) in sorted(list(case_fixed) + list(typo_fixed))])
 
 report_result(
-    'Fix field name %s in debian/tests/control (%s).' % (kind, fixed_str))
+    f'Fix field name {kind} in debian/tests/control ({fixed_str}).')
