@@ -45,7 +45,7 @@ with suppress(FileNotFoundError), \
         if (field.startswith('X-') and
                 field[2:] in valid_field_names):
             if field[2:] in updater.code:
-                warn('Both %s and %s exist.' % (
+                warn('Both {} and {} exist.'.format(
                      field, field[2:]))
                 continue
             value = updater.code[field]
@@ -76,8 +76,8 @@ if typo_fixed:
     kind += 'typo' + ('s' if len(typo_fixed) > 1 else '')
 
 fixed_str = ', '.join(
-    ['%s ⇒ %s' % (old, new)
+    [f'{old} ⇒ {new}'
      for (old, new) in sorted(list(case_fixed) + list(typo_fixed))])
 
 report_result(
-    'Fix field name %s in debian/upstream/metadata (%s).' % (kind, fixed_str))
+    f'Fix field name {kind} in debian/upstream/metadata ({fixed_str}).')
