@@ -1,13 +1,11 @@
 #!/usr/bin/python3
 
-from debmutate.control import ControlEditor
-
-from lintian_brush.fixer import report_result, LintianIssue
+from lintian_brush.fixer import control, report_result, LintianIssue
 
 updated_packages = set()
 
 
-with ControlEditor() as updater:
+with control as updater:
     for binary in updater.binaries:
         package = binary['Package']
         if (not package.startswith('fonts-') and
@@ -26,5 +24,5 @@ with ControlEditor() as updater:
 
 
 report_result(
-    'Set Multi-Arch: foreign on package%s %s.' % (
+    'Set Multi-Arch: foreign on package{} {}.'.format(
         's' if len(updated_packages) > 1 else '', ', '.join(updated_packages)))
