@@ -2,7 +2,7 @@
 
 import re
 
-from lintian_brush.fixer import fixed_lintian_tag, report_result
+from lintian_brush.fixer import LintianIssue, report_result
 
 with open('debian/copyright', 'rb') as f:
     lines = list(f)
@@ -12,12 +12,16 @@ m = re.match(
     rb'(http:\/\/www.debian.org\/doc\/packaging-manuals\/'
     rb'copyright-format\/1.0.*)\n', lines[0])
 if m:
-    lines[0] = (
+    newline = (
         b'Format: https://www.debian.org/doc/packaging-manuals/'
         b'copyright-format/1.0/\n')
-    with open('debian/copyright', 'wb') as f:
-        f.writelines(lines)
-    fixed_lintian_tag(
-        'source', 'insecure-copyright-format-uri', m.group(2).decode())
+    if newline != lines[0]:
+        lines[0] = newline
+        issue = LintianIssue(
+            'source', 'insecure-copyright-format-uri', m.group(2).decode())
+        if issue.should_fix():
+            with open('debian/copyright', 'wb') as f:
+                f.writelines(lines)
+            issue.report_fixed()
 
 report_result("Use secure copyright file specification URI.")
