@@ -1,15 +1,14 @@
 #!/usr/bin/python3
 
 from debmutate.control import (
-    ControlEditor,
     get_relation,
     drop_dependency,
     add_dependency,
     )
-from lintian_brush.fixer import report_result, LintianIssue
+from lintian_brush.fixer import control, report_result, LintianIssue
 
 
-with ControlEditor() as updater:
+with control as updater:
     try:
         get_relation(
             updater.source.get('Build-Depends-Indep', ''),
