@@ -1,7 +1,8 @@
 #!/usr/bin/python3
 
-from debmutate.control import ControlEditor
+from contextlib import suppress
 from lintian_brush.fixer import (
+    control,
     fixed_lintian_tag,
     report_result,
     )
@@ -13,7 +14,7 @@ import sys
 certainty = 'certain'
 updated = {}
 
-with ControlEditor() as updater:
+with control as updater:
     if updater.source.get('Priority'):
         sys.exit(0)
     binary_priorities = set()
@@ -31,10 +32,8 @@ with ControlEditor() as updater:
     if len(binary_priorities) == 1:
         updater.source['Priority'] = binary_priorities.pop()
         for binary in updater.binaries:
-            try:
+            with suppress(KeyError):
                 del binary['Priority']
-            except KeyError:
-                pass
         report_result(
             'Set priority in source stanza, since it is the same '
             'for all packages.',
