@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 
 from lintian_brush import (
+    DEFAULT_MINIMUM_CERTAINTY,
     min_certainty,
     )
 from lintian_brush.multiarch_hints import (
@@ -19,7 +20,9 @@ if os.environ.get('NET_ACCESS', 'disallow') != 'allow':
 with download_multiarch_hints() as f:
     hints = multiarch_hints_by_binary(parse_multiarch_hints(f))
 
-changes = apply_multiarch_hints(hints, os.environ.get('MINIMUM_CERTAINTY'))
+certainty = os.environ.get('MINIMUM_CERTAINTY', DEFAULT_MINIMUM_CERTAINTY)
+
+changes = apply_multiarch_hints(hints, certainty)
 
 overall_certainty = min_certainty(
     [certainty for (binary, hint, description, certainty) in changes])
@@ -28,4 +31,4 @@ print("Apply multi-arch hints.")
 print("")
 
 for (binary, _hint, description, _certainty) in changes:
-    print("* %s: %s" % (binary['Package'], description))
+    print("* {}: {}".format(binary['Package'], description))
