@@ -4,11 +4,14 @@ from lintian_brush.fixer import (
     opinionated,
     package_is_native,
     LintianIssue,
+    is_debcargo_package,
+    meets_minimum_certainty,
+    warn,
     )
 import os
 import sys
 
-if os.path.exists('debian/debcargo.toml'):
+if is_debcargo_package():
     sys.exit(0)
 
 description = None
@@ -23,7 +26,7 @@ if not os.path.exists('debian/source/format'):
     missing_source_format_issue.report_fixed()
     description = "Explicitly specify source format."
 else:
-    with open('debian/source/format', 'r') as f:
+    with open('debian/source/format') as f:
         format = orig_format = f.read().strip()
 
 if orig_format not in (None, '1.0'):
@@ -46,27 +49,28 @@ if older_source_format_issue.should_fix():
         patches_directory = find_patches_directory('.')
         if patches_directory not in ('debian/patches', None):
             # Non-standard patches directory.
-            sys.stderr.write(
-                'Tree has non-standard patches directory %s.\n' % (
+            warn(
+                'Tree has non-standard patches directory %s.' % (
                     patches_directory))
         else:
             try:
                 tree, path = WorkingTree.open_containing('.')
-            except errors.NotBranchError:
-                # TODO(jelmer): Or maybe don't do anything ?
+            except errors.NotBranchError as e:
+                if not meets_minimum_certainty('possible'):
+                    warn('unable to open vcs to check for delta: %s' % e)
+                    sys.exit(0)
                 format = "3.0 (quilt)"
                 description = "Upgrade to newer source format %s." % format
             else:
                 delta = list(tree_non_patches_changes(tree, patches_directory))
                 if delta:
-                    sys.stderr.write(
-                        'Tree has non-quilt changes against upstream.\n')
+                    warn('Tree has non-quilt changes against upstream.')
                     if opinionated():
                         format = "3.0 (quilt)"
                         description = (
                             "Upgrade to newer source format %s." % format)
                         try:
-                            with open('debian/source/options', 'r') as f:
+                            with open('debian/source/options') as f:
                                 options = list(f.readlines())
                         except FileNotFoundError:
                             options = []
