@@ -1,10 +1,7 @@
 #!/usr/bin/python3
 
 from debmutate.changelog import ChangelogEditor
-from debmutate.control import (
-    ControlEditor,
-    )
-from lintian_brush.fixer import report_result, fixed_lintian_tag
+from lintian_brush.fixer import control, report_result, fixed_lintian_tag
 
 from email.utils import parseaddr
 import sys
@@ -13,7 +10,7 @@ TEAM_UPLOAD_LINE = '  * Team upload.'
 uploader_emails = []
 
 
-with ControlEditor() as updater:
+with control as updater:
     for entry in updater.source.get('Uploaders', '').split(','):
         uploader_emails.append(parseaddr(entry)[1])
 
