@@ -1,6 +1,6 @@
 #!/usr/bin/python3
 
-from lintian_brush.fixer import control, report_result, fixed_lintian_tag
+from lintian_brush.fixer import control, report_result, LintianIssue
 from lintian_brush.vcs import canonicalize_vcs_url
 
 
@@ -14,10 +14,12 @@ with control as updater:
         new_value = canonicalize_vcs_url(
             name[len("Vcs-"):], updater.source[name])
         if new_value != updater.source[name]:
-            fixed_lintian_tag(
+            issue = LintianIssue(
                 updater.source, 'vcs-field-not-canonical',
-                '%s %s' % (updater.source[name], new_value))
-            updater.source[name] = new_value
-            fields.add(name)
+                f'{updater.source[name]} {new_value}')
+            if issue.should_fix():
+                issue.report_fixed()
+                updater.source[name] = new_value
+                fields.add(name)
 
 report_result("Use canonical URL in " + ', '.join(sorted(fields)) + '.')
