@@ -57,7 +57,7 @@ from breezy.workspace import reset_tree, check_clean_tree
 from debmutate.reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 146)
+__version__ = (0, 147)
 version_string = ".".join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ["certain", "confident", "likely", "possible", None]
 DEFAULT_MINIMUM_CERTAINTY = "certain"
@@ -660,7 +660,7 @@ def get_committer(tree: WorkingTree) -> str:
       A committer string
     """
     # TODO(jelmer): Perhaps this logic should be in Breezy?
-    if getattr(tree.branch.repository, "_git", None):
+    if hasattr(tree.branch.repository, "_git"):
         cs = tree.branch.repository._git.get_config_stack()
         user = os.environ.get("GIT_COMMITTER_NAME")
         email = os.environ.get("GIT_COMMITTER_EMAIL")
