@@ -446,7 +446,7 @@ def main(argv=None):  # noqa: C901
         if os.environ.get('SVP_API') == '1':
             applied = []
             if 'SVP_RESUME' in os.environ:
-                with open(os.environ['SVP_RESUME'], 'r') as f:
+                with open(os.environ['SVP_RESUME']) as f:
                     base = json.load(f)
                     applied.extend(base['applied'])
             for result, summary in overall_result.success:
@@ -455,6 +455,9 @@ def main(argv=None):  # noqa: C901
                         "summary": summary,
                         "description": result.description,
                         "fixed_lintian_tags": result.fixed_lintian_tags,
+                        "fixed_lintian_issues": [
+                            issue.json()
+                            for issue in result.fixed_lintian_issues],
                         "revision_id": result.revision_id.decode("utf-8"),
                         "certainty": result.certainty,
                     }
@@ -476,7 +479,6 @@ def main(argv=None):  # noqa: C901
                     'context': {
                         'applied': applied,
                         'failed': failed,
-
                     },
                     'versions': versions_dict(),
                 }, f)
