@@ -111,7 +111,7 @@ def get_overrides(
             )
 
     for path in paths:
-        with suppress(FileNotFoundError), open(path, "r") as f:
+        with suppress(FileNotFoundError), open(path) as f:
             yield from iter_overrides(f)
 
 
@@ -185,7 +185,7 @@ def remove_unused(
             if override.type not in (None, unused_override[1]):
                 continue
             if override.info:
-                expected_info = "%s %s" % (override.tag, override.info)
+                expected_info = f"{override.tag} {override.info}"
             else:
                 expected_info = override.tag
             if expected_info != unused_override[3]:
@@ -321,7 +321,7 @@ INFO_FIXERS = {
         (r"^(?P<path>[^[ ].+) \*", r"[\1]"),
         PURE_FN_SUB],
     "spelling-error-in-binary":
-        (r"^" + PATH_MATCH + " (.+) ([^[/\*]+)$", r"\2 \3 [\1]"),
+        (r"^" + PATH_MATCH + r" (.+) ([^[/\*]+)$", r"\2 \3 [\1]"),
     "very-long-line-length-in-source-file": [
         (PATH_MATCH +
          r" line ([0-9]+) is ([0-9]+) characters long \(>([0-9]+)\)",
@@ -372,6 +372,9 @@ INFO_FIXERS = {
         r"(choke on: \2) [\1]"),
     "systemd-service-file-refers-to-unusual-wantedby-target": (
         "^" + PATH_MATCH + r" ([^[ ]+)$", r"\2 [\1]"),
+    "duplicate-font-file": (
+        "^" + PATH_MATCH + r" also in ([^[]+)$",
+        r"also in (\2) [\1]"),
 }
 
 
@@ -391,7 +394,7 @@ def fix_override_info(override):
                 # The regex should only apply once
                 if re.sub(fixer[0], fixer[1], info) != info:
                     raise AssertionError(
-                        "invalid repeatable regex for %s: %s" % (
+                        "invalid repeatable regex for {}: {}".format(
                              override.tag, fixer[0]))
             elif callable(fixer):
                 info = fixer(info) or info
@@ -410,7 +413,7 @@ if __name__ == "__main__":
     args = parser.parse_args()
     if args.remove_unused:
         from debian.deb822 import Deb822
-        with open("debian/control", "r") as f:
+        with open("debian/control") as f:
             removed = remove_unused(Deb822.iter_paragraphs(f))
         print("Removed %d unused overrides" % len(removed))
     else:
