@@ -23,6 +23,7 @@ from contextlib import suppress
 import json
 import logging
 import os
+import sys
 from typing import List, Tuple, Optional, Dict, Callable, Union
 
 from breezy.commit import PointlessCommit, NullCommitReporter
@@ -904,6 +905,8 @@ def main():  # noqa: C901
                 "formatting-unpreservable",
                 "unable to preserve formatting while editing %s" % e.path,
             )
+            if hasattr(e, 'diff'):  # debmutate >= 0.64
+                sys.stderr.writelines(e.diff())
             return 1
         except GeneratedFile as e:
             report_fatal(
@@ -962,6 +965,4 @@ def main():  # noqa: C901
 
 
 if __name__ == "__main__":
-    import sys
-
     sys.exit(main())
