@@ -26,6 +26,10 @@ from lintian_brush.scrub_obsolete import (
     drop_obsolete_depends,
     release_aliases,
     PackageChecker,
+    DropEssential,
+    DropMinimumVersion,
+    DropTransition,
+    ReplaceTransition,
     )
 
 from debian.changelog import Version
@@ -68,7 +72,8 @@ class FilterRelationsTests(TestCase):
         def cb(oldrel):
             return [], oldrel
 
-        self.assertEqual(["foo"], filter_relations(control, "Depends", cb))
+        self.assertEqual(PkgRelation.parse("foo"),
+                         filter_relations(control, "Depends", cb))
         self.assertEqual({}, control)
 
     def test_drop(self):
@@ -79,7 +84,8 @@ class FilterRelationsTests(TestCase):
                 return [], oldrel
             return oldrel, []
 
-        self.assertEqual(["foo"], filter_relations(control, "Depends", cb))
+        self.assertEqual(PkgRelation.parse("foo"),
+                         filter_relations(control, "Depends", cb))
         self.assertEqual({"Depends": "bar"}, control)
 
     def test_keep_last_comma(self):
@@ -90,7 +96,8 @@ class FilterRelationsTests(TestCase):
                 return [], oldrel
             return oldrel, []
 
-        self.assertEqual(["foo"], filter_relations(control, "Depends", cb))
+        self.assertEqual(PkgRelation.parse("foo"),
+                         filter_relations(control, "Depends", cb))
         self.assertEqual({"Depends": "bar, "}, control)
 
     def test_drop_just_comma(self):
@@ -101,7 +108,8 @@ class FilterRelationsTests(TestCase):
                 return [], oldrel
             return oldrel, []
 
-        self.assertEqual(["foo"], filter_relations(control, "Depends", cb))
+        self.assertEqual(PkgRelation.parse("foo"),
+                         filter_relations(control, "Depends", cb))
         self.assertEqual({}, control)
 
 
@@ -109,9 +117,10 @@ class DummyChecker(PackageChecker):
 
     release = "release"
 
-    def __init__(self, versions, essential):
+    def __init__(self, versions, essential, *, transitions=None):
         self.versions = versions
         self.essential = essential
+        self._transitions = transitions or {}
 
     def package_version(self, package):
         return self.versions.get(package)
@@ -131,14 +140,14 @@ class DropObsoleteDependsTests(TestCase):
         orig = PkgRelation.parse('simple (>= 1.0)')
         self.assertEqual(
             (PkgRelation.parse('simple'),
-             PkgRelation.parse('simple (>= 1.0)')),
+             [DropMinimumVersion(*PkgRelation.parse('simple (>= 1.0)'))]),
             drop_obsolete_depends(orig, checker))
 
     def test_essential(self):
         checker = DummyChecker({'simple': Version('1.1')}, {'simple'})
         orig = PkgRelation.parse('simple (>= 1.0)')
         self.assertEqual(
-            ([], PkgRelation.parse('simple (>= 1.0)')),
+            ([], [DropEssential(*PkgRelation.parse('simple (>= 1.0)'))]),
             drop_obsolete_depends(orig, checker))
 
     def test_debhelper(self):
@@ -152,7 +161,40 @@ class DropObsoleteDependsTests(TestCase):
         checker = DummyChecker({'simple': Version('1.1')}, {'simple'})
         orig = PkgRelation.parse('simple (>= 1.0) | other')
         self.assertEqual(
-            ([], PkgRelation.parse('simple (>= 1.0) | other')),
+            ([],
+             [DropEssential(*PkgRelation.parse('simple (>= 1.0)'))]),
+            drop_obsolete_depends(orig, checker))
+
+    def test_transition(self):
+        checker = DummyChecker({'simple': Version('1.1')}, {'simple'},
+                               transitions={'oldpackage': 'replacement'})
+        orig = PkgRelation.parse('oldpackage (>= 1.0) | other')
+        self.assertEqual(
+            (PkgRelation.parse('replacement | other'),
+             [ReplaceTransition(PkgRelation.parse('oldpackage (>= 1.0)')[0],
+                                PkgRelation.parse('replacement'))]),
+            drop_obsolete_depends(orig, checker))
+
+    def test_transition_matches(self):
+        checker = DummyChecker({'simple': Version('1.1')}, {'simple'},
+                               transitions={'oldpackage': 'replacement'})
+        orig = PkgRelation.parse('oldpackage (>= 1.0) | replacement ')
+        self.assertEqual(
+            (PkgRelation.parse('replacement'),
+             [DropTransition(*PkgRelation.parse('oldpackage (>= 1.0)'))]),
+            drop_obsolete_depends(orig, checker))
+
+    def test_transition_dupes(self):
+        checker = DummyChecker({'simple': Version('1.1')}, {'simple'},
+                               transitions={'oldpackage': 'replacement'})
+        orig = PkgRelation.parse(
+            'oldpackage (>= 1.0) | oldpackage (= 3.0) | other')
+        self.assertEqual(
+            (PkgRelation.parse('replacement | other'),
+             [ReplaceTransition(PkgRelation.parse('oldpackage (>= 1.0)')[0],
+                                PkgRelation.parse('replacement')),
+              ReplaceTransition(PkgRelation.parse('oldpackage (= 3.0)')[0],
+                                PkgRelation.parse('replacement'))]),
             drop_obsolete_depends(orig, checker))
 
 
