@@ -70,7 +70,7 @@ def determine_gitlab_browser_url(url: str) -> str:
         path = path + "/tree/%s" % branch
     if subpath:
         path = path + "/" + subpath
-    return "https://%s%s" % (parsed_url.hostname, path)
+    return f"https://{parsed_url.hostname}{path}"
 
 
 def determine_browser_url(vcs_type, vcs_url: str) -> Optional[str]:
@@ -182,6 +182,7 @@ def canonicalize_vcs_url(vcs_type: str, url: str) -> str:
 
 
 def find_secure_vcs_url(url: str, net_access: bool = True) -> Optional[str]:
+    repo_url: Optional[str]
     (repo_url, branch, subpath) = split_vcs_url(url)
     repo_url = find_secure_repo_url(
         repo_url, branch=branch, net_access=net_access)
